@@ -291,7 +291,7 @@ class ColType_UUID(ColType, IKey):
 
 @attrs.define(frozen=True)
 class ColType_Alphanum(ColType, IKey):
-    python_type = ArithUnicodeString
+    python_type = ArithAlphanumeric
 
 
 @attrs.define(frozen=True)
@@ -321,7 +321,7 @@ class String_Alphanum(ColType_Alphanum, StringType):
     @staticmethod
     def test_value(value: str) -> bool:
         try:
-            ArithUnicodeString(value)
+            ArithAlphanumeric(value)
             return True
         except ValueError:
             return False
@@ -332,6 +332,11 @@ class String_VaryingAlphanum(String_Alphanum):
     pass
 
 
+@attrs.define(frozen=True)
+class String_VaryingUnicode(ColType_Unicode, StringType):
+    pass
+
+
 @attrs.define(frozen=True)
 class String_FixedAlphanum(String_Alphanum):
     length: int
