@@ -25,6 +25,9 @@ from typing import Any, Dict, Iterator, List, Optional, Set, Tuple, Union
 
 import attrs
 
+# logger = getLogger(__name__)
+from loguru import logger
+
 from data_diff.abcs.database_types import IKey
 from data_diff.errors import DataDiffMismatchingKeyTypesError
 from data_diff.info_tree import InfoTree, SegmentInfo
@@ -32,8 +35,6 @@ from data_diff.table_segment import TableSegment, create_mesh_from_points
 from data_diff.thread_utils import ThreadedYielder
 from data_diff.utils import Vector, getLogger, safezip
 
-logger = getLogger(__name__)
-
 
 class Algorithm(Enum):
     AUTO = "auto"
