@@ -446,6 +446,10 @@ class HashDiffer(TableDiffer):
         segment_index=None,
         segment_count=None,
     ):
+        # Check if level exceeds maximum allowed recursion depth
+        if level > 15:
+            raise RecursionError(f"Maximum recursion level exceeded: {level} > 15")
+
         # Initialize diff tracker if not already done
         self._initialize_diff_tracker(table1, table2)
 
@@ -547,6 +551,10 @@ class HashDiffer(TableDiffer):
         level=0,
         max_rows=None,
     ):
+        # Check if level exceeds maximum allowed recursion depth
+        if level > 15:
+            raise RecursionError(f"Maximum recursion level exceeded: {level} > 15")
+
         assert table1.is_bounded and table2.is_bounded
 
         # Initialize diff tracker if not already done
