@@ -359,7 +359,15 @@ class TableSegment:
                         continue
                     mk_v = schema.make_value(val)
                     constant_val = self.database.dialect._constant_value(mk_v)
-                    where_expr = f"{quoted} = {constant_val}"
+
+                    # Special handling for Sybase timestamp equality to handle precision mismatches
+                    if hasattr(self.database.dialect, "timestamp_equality_condition") and hasattr(
+                        mk_v, "_dt"
+                    ):  # Check if it's a datetime-like object
+                        where_expr = self.database.dialect.timestamp_equality_condition(quoted, constant_val)
+                    else:
+                        where_expr = f"{quoted} = {constant_val}"
+
                     and_exprs.append(Code(where_expr))
                 if and_exprs:
                     key_exprs.append(and_(*and_exprs))
