@@ -188,18 +188,24 @@ def _any_to_datetime(v: Union[str, datetime, date, "ArithDateTime"]) -> datetime
     elif isinstance(v, date):
         return datetime.combine(v, time.min)
     elif isinstance(v, str):
-        # Try to parse ISO format strings
+        # Try specific formats first to preserve original precision
         try:
-            return datetime.fromisoformat(v.replace("Z", "+00:00"))
+            # Handle format: YYYY-MM-DD HH:MM:SS.mmm (3-digit milliseconds)
+            return datetime.strptime(v, "%Y-%m-%d %H:%M:%S.%f")
         except ValueError:
-            # Fallback parsing for other common formats
             try:
+                # Handle format: YYYY-MM-DD HH:MM:SS
                 return datetime.strptime(v, "%Y-%m-%d %H:%M:%S")
             except ValueError:
                 try:
+                    # Handle format: YYYY-MM-DD
                     return datetime.strptime(v, "%Y-%m-%d")
                 except ValueError:
-                    raise ValueError(f"Cannot parse datetime string: {v!r}")
+                    # Last resort: try ISO format parsing
+                    try:
+                        return datetime.fromisoformat(v.replace("Z", "+00:00"))
+                    except ValueError:
+                        raise ValueError(f"Cannot parse datetime string: {v!r}")
     else:
         raise ValueError(f"Cannot convert value to datetime: {v!r}")
 
